@@ -7,6 +7,7 @@
 #' @template moreargs
 #' @template cursor_args
 #' @template field_queries
+#' @template sorting
 #' @param facet (logical) Include facet results. Boolean or string with
 #' field to facet on. Valid fields are *, affiliation, funder-name,
 #' funder-doi, orcid, container-title, assertion, archive, update-type,
@@ -75,12 +76,17 @@
 #' # field queries
 #' ## query.author
 #' cr_journals("2167-8359", works = TRUE, flq = c(`query.author` = 'Jane'))
+#' 
+#' # select only certain fields to return
+#' res <- cr_journals('2167-8359', works = TRUE, 
+#'   select = c('DOI', 'title'))
+#' names(res$data)
 #' }
 
 `cr_journals` <- function(issn = NULL, query = NULL, filter = NULL,
   offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL,
   facet = FALSE, works=FALSE, cursor = NULL, cursor_max = 5000,
-  .progress="none", flq = NULL, ...) {
+  .progress="none", flq = NULL, select = NULL, ...) {
 
   if (works) {
     if (is.null(issn)) {
@@ -88,7 +94,7 @@
     }
   }
   args <- prep_args(query, filter, offset, limit, sample,
-                    sort, order, facet, cursor, flq)
+                    sort, order, facet, cursor, flq, select)
 
   if (length(issn) > 1) {
     res <- llply(issn, journal_GET, args = args, works = works,
@@ -151,7 +157,7 @@
 `cr_journals_` <- function(issn = NULL, query = NULL, filter = NULL,
   offset = NULL, limit = NULL, sample = NULL, sort = NULL, order = NULL,
   facet = FALSE, works=FALSE, cursor = NULL, cursor_max = 5000,
-  .progress="none", parse=FALSE, flq = NULL, ...) {
+  .progress="none", parse=FALSE, flq = NULL, select = NULL, ...) {
 
   if (works) {
     if (is.null(issn)) {
@@ -159,7 +165,7 @@
     }
   }
   args <- prep_args(query, filter, offset, limit, sample, sort, order,
-                    facet, cursor, flq)
+                    facet, cursor, flq, select)
   if (length(issn) > 1) {
     llply(issn, journal_GET_, args = args, works = works,
           cursor = cursor, cursor_max = cursor_max,
